
#include "Time.h"  
#include <ESP8266WiFi.h>
#include <WiFiUdp.h>

#include "SDA5708_ESP.h"
#include "Time_NTP.h"

const char* ssid = "NexxHome";
const char* password = "d0mdeQjv";

char previousSecond = 0;

void WiFiStart(void);
void Get_NTP(void);
void ShowDate(void);
void ShowTime(void);

// create instance of display -> calls constructor which does the init, set pins as parameters
// SDA5708 sda5708(LOAD, DATA, SDCLK, RESET);
SDA5708 sda5708( 4, 12, 14, 13);

void setup()
  {
    // set brightness 
    // 0 == max, 7 == off, +8 reduziert Mux-Impulslänge
    sda5708.set_brightness(5);

    sda5708.print2display("HomeLabs");
    
    Serial.begin(115200);
    Serial.print("setup begin\r\n");

    // inital connect
    WiFi.mode(WIFI_STA);
    WiFiStart();

    Get_NTP();   
}

void loop()
  {
    if (previousSecond != second())   // neue Sekunde?
      {
        previousSecond = second();    // ja, aktuelle Sekunde merken

        if (second()%15 < 2)          // alle 15 Sekunden für 2 Sekunden Datum anzeigen 
          {
            ShowDate();
          }
        else
          {  
            ShowTime();
          }
        if ((hour() == 2) && (minute() == 2) && (second() == 0))  // NTP Zeit holen um 02:02:00 Uhr
          {
            Get_NTP();       
          }
      }
  }

//---------------------------------------------------------------------

void WiFiStart()
  { 
    // Connect to WiFi network
    Serial.println();
    Serial.println();
    Serial.print("Connecting to ");
    Serial.println(ssid);
  
    WiFi.begin(ssid, password);
  
    while (WiFi.status() != WL_CONNECTED)
      {
        delay(500);
        Serial.print(".");
      }
    Serial.println("");
    Serial.println("WiFi connected");
  
    // Print the IP address
    Serial.println(WiFi.localIP());
  }

//---------------------------------------------------------------------

void Get_NTP()
  {
    if (WiFi.status() != WL_CONNECTED)
      {
            WiFiStart();
      }
      
    ///////////////////////////////
    // connect to NTP and get time
    ///////////////////////////////

    unsigned long ulSecs2000_timer = 0;
    date_time_t datum_zeit;

    ulSecs2000_timer = getNTPTimestamp();
    Serial.print("Current Time Seconds: " );
    Serial.println(ulSecs2000_timer,DEC);

    epoch_to_date_time(&datum_zeit, (ulSecs2000_timer + 3600));
    Serial.println("");
    Serial.print(datum_zeit.hour,DEC);
    Serial.print(":");
    Serial.print(datum_zeit.minute,DEC);
    Serial.print(":");
    Serial.print(datum_zeit.second,DEC);
    Serial.print(" ");
    Serial.print(datum_zeit.day,DEC);
    Serial.print(".");
    Serial.print(datum_zeit.month,DEC);
    Serial.print(".");
    Serial.print(datum_zeit.year,DEC);
    Serial.println("");
     
    setTime(datum_zeit.hour+2,datum_zeit.minute,datum_zeit.second,datum_zeit.day,datum_zeit.month,datum_zeit.year);
  }  

//---------------------------------------------------------------------

void ShowTime()
  {
    String stunden = String(hour(),DEC);
    if (hour() < 10)
      {
        stunden = "0" + stunden;
      }
    String minuten = String(minute(),DEC);
    if (minute() < 10)
      {
        minuten = "0" + minuten;
      }    
    String sekunden = String(second(),DEC);
    if (second() < 10)
      {
        sekunden = "0" + sekunden;
      }

    String uhrzeit = stunden + ':' + minuten + ':' + sekunden;
    sda5708.print2display(uhrzeit);
  } 

//---------------------------------------------------------------------

void ShowDate()
  {
    String tag = String(day(),DEC);
    if (day() < 10)
      {
        tag = "0" + tag;
      }
    String monat = String(month(),DEC);
    if (month() < 10)
      {
        monat = "0" + monat;
      }    
    String jahr = String(year(),DEC);

    String datum = tag + '.' + monat + '.' + jahr.substring(2);
    sda5708.print2display(datum);
  }     
